@@ -1,7 +1,8 @@
-#!/usr/bin/env python
-"""Usage: blobberc.py -u URL... -b BRANCH [-v] [-d] FILE
+#/opt/python/ondeck/wsgi.conf!/usr/bin/env python
+"""Usage: blobberc.py -u URL... -a AUTH_FILE -b BRANCH [-v] [-d] FILE
 
 -u, --url URL          URL to blobber server to upload to.
+-a, --auth AUTH_FILE   user/pass AUTH_FILE for signing the calls
 -b, --branch BRANCH    Specify branch for the file (e.g. try, mozilla-central)
 -v, --verbose          Increase verbosity
 -d, --dir              Instead of a file, upload multiple files from a dir name
@@ -10,14 +11,13 @@ FILE                   Local file(s) to upload
 """
 import urlparse
 import os
-import urllib2
 import hashlib
 import requests
-import poster.encode
 import logging
 import random
 from functools import partial
 
+from blobuploader import cert
 
 log = logging.getLogger(__name__)
 
@@ -34,8 +34,8 @@ sha512sum = partial(filehash, hashalgo='sha512')
 s3_bucket_base_url = 'http://mozilla-releng-blobs.s3.amazonaws.com/blobs'
 
 
-def upload_file(hosts, filename, branch, hashalgo='sha512',
-                blobhash=None, attempts=2):
+def upload_file(hosts, filename, branch, auth, hashalgo='sha512',
+                blobhash=None, attempts=10):
 
     if blobhash is None:
         blobhash = filehash(filename, hashalgo)
@@ -49,13 +49,15 @@ def upload_file(hosts, filename, branch, hashalgo='sha512',
         log.info("Picked up %s host after shuffling." % host)
         post_params = {
             'host': host,
+            'auth': auth,
             'filename': filename,
             'branch': branch,
             'hashalgo': hashalgo,
             'blobhash': blobhash,
         }
         log.info("POST call the file - attempt #%d." % (n))
-        if _post_file(**post_params):
+        ret_code = _post_file(**post_params)
+        if ret_code == 202:
             # File posted successfully via blob server.
             # Make sure the resource is available on amazon S3 bucket.
             resource_url = '%s/%s/%s/%s' % (s3_bucket_base_url, branch,
@@ -66,6 +68,8 @@ def upload_file(hosts, filename, branch, hashalgo='sha512',
             else:
                 log.warning("Uploading to Amazon S3 failed.")
             break
+        elif ret_code == 403 or ret_code == 401:
+            break
         else:
             log.warning("POST call failed. Trying again ...")
 
@@ -76,29 +80,33 @@ def upload_file(hosts, filename, branch, hashalgo='sha512',
                  (filename))
 
 
-def _post_file(host, filename, branch, hashalgo, blobhash):
+def _post_file(host, auth, filename, branch, hashalgo, blobhash):
     url = urlparse.urljoin(host, '/blobs/{}/{}'.format(hashalgo, blobhash))
 
-    datagen, headers = poster.encode.multipart_encode({
-        'data': open(filename, 'rb'),
-        'filename': filename,
-        'filesize': os.path.getsize(filename),
+    data_dict = {
+        'blob': open(filename, "rb"),
+    }
+
+    meta_dict = {
         'branch': branch,
-        'mimetype': 'application/octet-stream',
-    })
-    req = urllib2.Request(url, datagen, headers)
+    }
+
     log.debug("Posting file to %s ...", url)
-    try:
-        urllib2.urlopen(req)
-    except urllib2.URLError:
-        log.debug("Posting file %s failed." % filename)
-        return False
+    req = requests.post(url,
+                        auth=auth,
+                        files=data_dict,
+                        data=meta_dict,
+                        verify=cert.where())
 
-    log.debug("Posting file %s sucessfully." % filename)
-    return True
+    if req.status_code != 202:
+        err_msg = req.headers.get('x-blobber-msg',
+                                  'Something went wrong on blobber!')
+        log.warning(err_msg)
+
+    return req.status_code
 
 
-def upload_dir(hosts, dirname, branch, hashalgo='sha512'):
+def upload_dir(hosts, dirname, branch, auth, hashalgo='sha512'):
     log.info("Open directory for files ...")
     dir_files = [f for f in os.listdir(dirname)
                  if os.path.isfile(os.path.join(dirname, f))]
@@ -106,15 +114,13 @@ def upload_dir(hosts, dirname, branch, hashalgo='sha512'):
     log.debug("Go through all files in directory")
     for f in dir_files:
         filename = os.path.join(dirname, f)
-        upload_file(hosts, filename, branch)
+        upload_file(hosts, filename, branch, auth)
 
     log.info("Iteration through files over.")
 
 
 def main():
     from docopt import docopt
-    import poster.streaminghttp
-    poster.streaminghttp.register_openers()
 
     args = docopt(__doc__)
 
@@ -127,12 +133,22 @@ def main():
     logging.basicConfig(format=FORMAT, level=loglevel)
     logging.getLogger('requests').setLevel(logging.WARN)
 
+    credentials = {}
+    execfile(args['--auth'], credentials)
+    auth = (credentials['blobber_username'], credentials['blobber_password'])
+
     if args['--dir']:
         if os.path.isdir(args['FILE']):
-            upload_dir(args['--url'], args['FILE'], branch=args['--branch'])
+            upload_dir(args['--url'],
+                       args['FILE'],
+                       args['--branch'],
+                       auth)
     else:
         if os.path.isfile(args['FILE']):
-            upload_file(args['--url'], args['FILE'], branch=args['--branch'])
+            upload_file(args['--url'],
+                        args['FILE'],
+                        args['--branch'],
+                        auth)
 
 if __name__ == '__main__':
     main()
